#' Learning Curves dataset
#'
#' A dataset containing the learning curves used in the paper
#' Reetzke et al. (2018), "Tracing the Trajectory of Sensory Plasticity across
#' Different Stages of Speech Learning in Adulthood".
#'
#' * `ind` label denoting the individual
#' * `time` time (number of days)
#' * `succ` number of successfull answers
#' * `ni` number of trials
#'
#' @format A data frame with 314 rows and 4 variables
#' @source <https://data.mendeley.com/datasets/j2z2km4p9y/2>
#' @examples
#' require(ggplot2)
#' data(learnCurve)
#' jit_data <- learnCurve
#' jit_data$time <- jitter(learnCurve$time)
#' ggplot() +
#'     geom_point(aes(x = time, y = succ/ni),
#'         col = rgb(0.75, 0.75, 0.75, 0.8), pch = 16, size = 2,
#'         data = jit_data) +
#'     geom_line(aes(x = time, y = succ/ni, group = ind), size = 0.5,
#'         col = rgb(0.75, 0.75, 0.75, 1), data = jit_data) +
#'     scale_color_brewer(name="", palette = "Set1") +
#'     theme(legend.position="none") +
#'     labs(x = 'Time', y = 'Probability', title = 'Empirical probabilities of
#'         success across trials')
#'
"learnCurve"
