% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{bin_logit_randspline}
\alias{bin_logit_randspline}
\title{Functional Logistic Mixed Effects Model}
\usage{
bin_logit_randspline(y, X, Z, ind, ni, time, x_grid, z_grid, hypers, Niter,
  burnin, thin)
}
\arguments{
\item{y}{vector of observations (number of observed successes for each individual n = 1, ..., N, for each time point t = 1, ..., T)}

\item{X}{matrix of fixed covariates (in the spline case, it is just the vector of time points corresponding to y expanded on the Spline basis)}

\item{Z}{matrix of random effects (in the spline case, it is just the vector of time points corresponding to y expanded on the Spline basis)}

\item{ind}{vector of identifiers for the individuals, corresponding to the observations y (ind_i == j means that y_i is associated to the individual j)}

\item{ni}{vector of number of trials}

\item{time}{vector of time indicators for each observation y}

\item{x_grid}{matrix of the grid where to evaluate the function \eqn{\mu(t)} expanded on the Spline basis)}

\item{z_grid}{matrix of the grid where to evaluate the function \eqn{\xi(t)} expanded on the Spline basis)}

\item{hypers}{hyperparameters (P, a_beta, b_beta)}

\item{Niter}{number of iterations}

\item{burnin}{burnin length}

\item{thin}{thinning factor}
}
\value{
object with MCMC output
\itemize{
\item \code{beta}: posterior distribution of the spline coefficients
\item \code{sigma2_b}: variance of the betas (smoothness penalty)
\item \code{pi}: curve on the probability scale (evaluated on x_grid)
\item \code{mu}: curve on the logit scale (evaluated on x_grid)
\item \code{sigma2_u}: variance of the random effects
\item \code{u}: random intercept curves for each individual
}
}
\description{
Binomial logistic nonparametric model with random effects, fitting a global curve \eqn{mu(t)} on the logit scale via penalized B-splines plus a random effect, i.e.
\eqn{logit(\pi_i(t)) = \mu(t) + \xi(t) \eta_i}
}
